@@ -21,41 +21,68 @@ module RuboCop
     class Node < Parser::AST::Node # rubocop:disable Metrics/ClassLength
       include RuboCop::AST::Sexp
       extend NodePattern::Macros
+      include RuboCop::AST::Descendence
 
+      # @api private
       # <=> isn't included here, because it doesn't return a boolean.
-      COMPARISON_OPERATORS = %i[== === != <= >= > <].freeze
+      COMPARISON_OPERATORS = %i[== === != <= >= > <].to_set.freeze
 
+      # @api private
       TRUTHY_LITERALS = %i[str dstr xstr int float sym dsym array
                            hash regexp true irange erange complex
-                           rational regopt].freeze
-      FALSEY_LITERALS = %i[false nil].freeze
+                           rational regopt].to_set.freeze
+      # @api private
+      FALSEY_LITERALS = %i[false nil].to_set.freeze
+      # @api private
       LITERALS = (TRUTHY_LITERALS + FALSEY_LITERALS).freeze
+      # @api private
       COMPOSITE_LITERALS = %i[dstr xstr dsym array hash irange
-                              erange regexp].freeze
+                              erange regexp].to_set.freeze
+      # @api private
       BASIC_LITERALS = (LITERALS - COMPOSITE_LITERALS).freeze
+      # @api private
       MUTABLE_LITERALS = %i[str dstr xstr array hash
-                            regexp irange erange].freeze
+                            regexp irange erange].to_set.freeze
+      # @api private
       IMMUTABLE_LITERALS = (LITERALS - MUTABLE_LITERALS).freeze
 
+      # @api private
       EQUALS_ASSIGNMENTS = %i[lvasgn ivasgn cvasgn gvasgn
-                              casgn masgn rasgn mrasgn].freeze
-      SHORTHAND_ASSIGNMENTS = %i[op_asgn or_asgn and_asgn].freeze
+                              casgn masgn].to_set.freeze
+      # @api private
+      SHORTHAND_ASSIGNMENTS = %i[op_asgn or_asgn and_asgn].to_set.freeze
+      # @api private
       ASSIGNMENTS = (EQUALS_ASSIGNMENTS + SHORTHAND_ASSIGNMENTS).freeze
 
-      BASIC_CONDITIONALS = %i[if while until].freeze
-      CONDITIONALS = [*BASIC_CONDITIONALS, :case].freeze
-      POST_CONDITION_LOOP_TYPES = %i[while_post until_post].freeze
+      # @api private
+      BASIC_CONDITIONALS = %i[if while until].to_set.freeze
+      # @api private
+      CONDITIONALS = (BASIC_CONDITIONALS + %i[case case_match]).freeze
+      # @api private
+      POST_CONDITION_LOOP_TYPES = %i[while_post until_post].to_set.freeze
+      # @api private
       LOOP_TYPES = (POST_CONDITION_LOOP_TYPES + %i[while until for]).freeze
-      VARIABLES = %i[ivar gvar cvar lvar].freeze
-      REFERENCES = %i[nth_ref back_ref].freeze
+      # @api private
+      VARIABLES = %i[ivar gvar cvar lvar].to_set.freeze
+      # @api private
+      REFERENCES = %i[nth_ref back_ref].to_set.freeze
+      # @api private
       KEYWORDS = %i[alias and break case class def defs defined?
                     kwbegin do else ensure for if module next
                     not or postexe redo rescue retry return self
                     super zsuper then undef until when while
-                    yield].freeze
-      OPERATOR_KEYWORDS = %i[and or].freeze
-      SPECIAL_KEYWORDS = %w[__FILE__ __LINE__ __ENCODING__].freeze
-      ARGUMENT_TYPES = %i[arg optarg restarg kwarg kwoptarg kwrestarg blockarg].freeze
+                    yield].to_set.freeze
+      # @api private
+      OPERATOR_KEYWORDS = %i[and or].to_set.freeze
+      # @api private
+      SPECIAL_KEYWORDS = %w[__FILE__ __LINE__ __ENCODING__].to_set.freeze
+      # @api private
+      ARGUMENT_TYPES = %i[arg optarg restarg kwarg kwoptarg kwrestarg
+                          blockarg forward_arg shadowarg].to_set.freeze
+
+      LITERAL_RECURSIVE_METHODS = (COMPARISON_OPERATORS + %i[* ! <=>]).freeze
+      LITERAL_RECURSIVE_TYPES = (OPERATOR_KEYWORDS + COMPOSITE_LITERALS + %i[begin pair]).freeze
+      private_constant :LITERAL_RECURSIVE_METHODS, :LITERAL_RECURSIVE_TYPES
 
       # @see https://www.rubydoc.info/gems/ast/AST/Node:initialize
       def initialize(type, children = [], properties = {})
@@ -167,7 +194,7 @@ module RuboCop
       def right_siblings
         return [].freeze unless parent
 
-        parent.children[sibling_index + 1..-1].freeze
+        parent.children[sibling_index + 1..].freeze
       end
 
       # Common destructuring method. This can be used to normalize
@@ -196,7 +223,7 @@ module RuboCop
       # @return [self] if a block is given
       # @return [Enumerator] if no block is given
       def each_ancestor(*types, &block)
-        return to_enum(__method__, *types) unless block_given?
+        return to_enum(__method__, *types) unless block
 
         visit_ancestors(types, &block)
 
@@ -211,105 +238,7 @@ module RuboCop
         each_ancestor.to_a
       end
 
-      # Calls the given block for each child node.
-      # If no block is given, an `Enumerator` is returned.
-      #
-      # Note that this is different from `node.children.each { |child| ... }`
-      # which yields all children including non-node elements.
-      #
-      # @overload each_child_node
-      #   Yield all nodes.
-      # @overload each_child_node(type)
-      #   Yield only nodes matching the type.
-      #   @param [Symbol] type a node type
-      # @overload each_child_node(type_a, type_b, ...)
-      #   Yield only nodes matching any of the types.
-      #   @param [Symbol] type_a a node type
-      #   @param [Symbol] type_b a node type
-      # @yieldparam [Node] node each child node
-      # @return [self] if a block is given
-      # @return [Enumerator] if no block is given
-      def each_child_node(*types)
-        return to_enum(__method__, *types) unless block_given?
-
-        children.each do |child|
-          next unless child.is_a?(Node)
-
-          yield child if types.empty? || types.include?(child.type)
-        end
-
-        self
-      end
-
-      # Returns an array of child nodes.
-      # This is a shorthand for `node.each_child_node.to_a`.
-      #
-      # @return [Array<Node>] an array of child nodes
-      def child_nodes
-        each_child_node.to_a
-      end
-
-      # Calls the given block for each descendant node with depth first order.
-      # If no block is given, an `Enumerator` is returned.
-      #
-      # @overload each_descendant
-      #   Yield all nodes.
-      # @overload each_descendant(type)
-      #   Yield only nodes matching the type.
-      #   @param [Symbol] type a node type
-      # @overload each_descendant(type_a, type_b, ...)
-      #   Yield only nodes matching any of the types.
-      #   @param [Symbol] type_a a node type
-      #   @param [Symbol] type_b a node type
-      # @yieldparam [Node] node each descendant node
-      # @return [self] if a block is given
-      # @return [Enumerator] if no block is given
-      def each_descendant(*types, &block)
-        return to_enum(__method__, *types) unless block_given?
-
-        visit_descendants(types, &block)
-
-        self
-      end
-
-      # Returns an array of descendant nodes.
-      # This is a shorthand for `node.each_descendant.to_a`.
-      #
-      # @return [Array<Node>] an array of descendant nodes
-      def descendants
-        each_descendant.to_a
-      end
-
-      # Calls the given block for the receiver and each descendant node in
-      # depth-first order.
-      # If no block is given, an `Enumerator` is returned.
-      #
-      # This method would be useful when you treat the receiver node as the root
-      # of a tree and want to iterate over all nodes in the tree.
-      #
-      # @overload each_node
-      #   Yield all nodes.
-      # @overload each_node(type)
-      #   Yield only nodes matching the type.
-      #   @param [Symbol] type a node type
-      # @overload each_node(type_a, type_b, ...)
-      #   Yield only nodes matching any of the types.
-      #   @param [Symbol] type_a a node type
-      #   @param [Symbol] type_b a node type
-      # @yieldparam [Node] node each node
-      # @return [self] if a block is given
-      # @return [Enumerator] if no block is given
-      def each_node(*types, &block)
-        return to_enum(__method__, *types) unless block_given?
-
-        yield self if types.empty? || types.include?(type)
-
-        visit_descendants(types, &block)
-
-        self
-      end
-
-      # Note: Some rare nodes may have no source, like `s(:args)` in `foo {}`
+      # NOTE: Some rare nodes may have no source, like `s(:args)` in `foo {}`
       # @return [String, nil]
       def source
         loc.expression&.source
@@ -343,10 +272,12 @@ module RuboCop
 
       ## Destructuring
 
+      # @!method receiver(node = self)
       def_node_matcher :receiver, <<~PATTERN
-        {(send $_ ...) ({block numblock} (send $_ ...) ...)}
+        {(send $_ ...) ({block numblock} (call $_ ...) ...)}
       PATTERN
 
+      # @!method str_content(node = self)
       def_node_matcher :str_content, '(str $_)'
 
       def const_name
@@ -360,6 +291,7 @@ module RuboCop
         end
       end
 
+      # @!method defined_module0(node = self)
       def_node_matcher :defined_module0, <<~PATTERN
         {(class (const $_ $_) ...)
          (module (const $_ $_) ...)
@@ -385,7 +317,11 @@ module RuboCop
         # returns nil if answer cannot be determined
         ancestors = each_ancestor(:class, :module, :sclass, :casgn, :block)
         result    = ancestors.map do |ancestor|
-          parent_module_name_part(ancestor) { |full_name| return full_name }
+          parent_module_name_part(ancestor) do |full_name|
+            return nil unless full_name
+
+            full_name
+          end
         end.compact.reverse.join('::')
         result.empty? ? 'Object' : result
       end
@@ -405,6 +341,7 @@ module RuboCop
       end
 
       # Some cops treat the shovel operator as a kind of assignment.
+      # @!method assignment_or_similar?(node = self)
       def_node_matcher :assignment_or_similar?, <<~PATTERN
         {assignment? (send _recv :<< ...)}
       PATTERN
@@ -439,10 +376,10 @@ module RuboCop
         define_method(recursive_kind) do
           case type
           when :send
-            [*COMPARISON_OPERATORS, :!, :<=>].include?(method_name) &&
+            LITERAL_RECURSIVE_METHODS.include?(method_name) &&
               receiver.send(recursive_kind) &&
               arguments.all?(&recursive_kind)
-          when :begin, :pair, *OPERATOR_KEYWORDS, *COMPOSITE_LITERALS
+          when LITERAL_RECURSIVE_TYPES
             children.compact.all?(&recursive_kind)
           else
             send(kind_filter)
@@ -482,13 +419,13 @@ module RuboCop
         POST_CONDITION_LOOP_TYPES.include?(type)
       end
 
-      # Note: `loop { }` is a normal method call and thus not a loop keyword.
+      # NOTE: `loop { }` is a normal method call and thus not a loop keyword.
       def loop_keyword?
         LOOP_TYPES.include?(type)
       end
 
       def keyword?
-        return true if special_keyword? || send_type? && prefix_not?
+        return true if special_keyword? || (send_type? && prefix_not?)
         return false unless KEYWORDS.include?(type)
 
         !OPERATOR_KEYWORDS.include?(type) || loc.operator.is?(type.to_s)
@@ -527,7 +464,7 @@ module RuboCop
       end
 
       def numeric_type?
-        int_type? || float_type?
+        int_type? || float_type? || rational_type? || complex_type?
       end
 
       def range_type?
@@ -540,39 +477,50 @@ module RuboCop
         node.match_guard_clause?
       end
 
+      # @!method match_guard_clause?(node = self)
       def_node_matcher :match_guard_clause?, <<~PATTERN
         [${(send nil? {:raise :fail} ...) return break next} single_line?]
       PATTERN
 
+      # @!method proc?(node = self)
       def_node_matcher :proc?, <<~PATTERN
         {(block (send nil? :proc) ...)
          (block (send #global_const?(:Proc) :new) ...)
          (send #global_const?(:Proc) :new)}
       PATTERN
 
+      # @!method lambda?(node = self)
       def_node_matcher :lambda?, '({block numblock} (send nil? :lambda) ...)'
+
+      # @!method lambda_or_proc?(node = self)
       def_node_matcher :lambda_or_proc?, '{lambda? proc?}'
 
+      # @!method global_const?(node = self, name)
       def_node_matcher :global_const?, '(const {nil? cbase} %1)'
 
+      # @!method class_constructor?(node = self)
       def_node_matcher :class_constructor?, <<~PATTERN
-        {       (send #global_const?({:Class :Module}) :new ...)
-         (block (send #global_const?({:Class :Module}) :new ...) ...)}
+        {       (send #global_const?({:Class :Module :Struct}) :new ...)
+         (block (send #global_const?({:Class :Module :Struct}) :new ...) ...)}
       PATTERN
 
+      # @deprecated Use `:class_constructor?`
+      # @!method struct_constructor?(node = self)
       def_node_matcher :struct_constructor?, <<~PATTERN
-        (block (send #global_const?(:Struct) :new ...) _ $_)
+        ({block numblock} (send #global_const?(:Struct) :new ...) _ $_)
       PATTERN
 
+      # @!method class_definition?(node = self)
       def_node_matcher :class_definition?, <<~PATTERN
         {(class _ _ $_)
          (sclass _ $_)
-         (block (send #global_const?({:Struct :Class}) :new ...) _ $_)}
+         ({block numblock} (send #global_const?({:Struct :Class}) :new ...) _ $_)}
       PATTERN
 
+      # @!method module_definition?(node = self)
       def_node_matcher :module_definition?, <<~PATTERN
         {(module _ $_)
-         (block (send #global_const?(:Module) :new ...) _ $_)}
+         ({block numblock} (send #global_const?(:Module) :new ...) _ $_)}
       PATTERN
 
       # Some expressions are evaluated for their value, some for their side
@@ -631,15 +579,6 @@ module RuboCop
         end
       end
 
-      protected
-
-      def visit_descendants(types, &block)
-        each_child_node do |child|
-          yield child if types.empty? || types.include?(child.type)
-          child.visit_descendants(types, &block)
-        end
-      end
-
       private
 
       def visit_ancestors(types)
@@ -712,6 +651,7 @@ module RuboCop
         end
       end
 
+      # @!method new_class_or_module_block?(node = self)
       def_node_matcher :new_class_or_module_block?, <<~PATTERN
         ^(casgn _ _ (block (send (const _ {:Class :Module}) :new) ...))
       PATTERN
