@@ -12,6 +12,7 @@ module RuboCop
       include MethodIdentifierPredicates
 
       VOID_CONTEXT_METHODS = %i[each tap].freeze
+      private_constant :VOID_CONTEXT_METHODS
 
       # The `send` node associated with this block.
       #
@@ -21,6 +22,9 @@ module RuboCop
       end
 
       # The arguments of this block.
+      # Note that if the block has destructured arguments, `arguments` will
+      # return a `mlhs` node, whereas `argument_list` will return only
+      # actual argument nodes.
       #
       # @return [Array<Node>]
       def arguments
@@ -31,6 +35,18 @@ module RuboCop
         end
       end
 
+      # Returns a collection of all descendants of this node that are
+      # argument type nodes. See `ArgsNode#argument_list` for details.
+      #
+      # @return [Array<Node>]
+      def argument_list
+        if numblock_type?
+          numbered_arguments
+        else
+          arguments.argument_list
+        end
+      end
+
       # The body of this block.
       #
       # @return [Node, nil] the body of the `block` node or `nil`
@@ -116,6 +132,18 @@ module RuboCop
       def void_context?
         VOID_CONTEXT_METHODS.include?(method_name)
       end
+
+      private
+
+      # Numbered arguments of this `numblock`.
+      def numbered_arguments
+        return [].freeze unless numblock_type?
+
+        max_param = children[1]
+        1.upto(max_param).map do |i|
+          ArgNode.new(:arg, [:"_#{i}"])
+        end.freeze
+      end
     end
   end
 end
