@@ -11,8 +11,10 @@ module RuboCop
         i: Regexp::IGNORECASE,
         m: Regexp::MULTILINE,
         n: Regexp::NOENCODING,
+        u: Regexp::FIXEDENCODING,
         o: 0
       }.freeze
+      private_constant :OPTIONS
 
       # @return [Regexp] a regexp of this node
       def to_regexp
@@ -24,7 +26,7 @@ module RuboCop
         children.last
       end
 
-      # Note: The 'o' option is ignored.
+      # NOTE: The 'o' option is ignored.
       #
       # @return [Integer] the Regexp option bits as returned by Regexp#options
       def options
@@ -86,6 +88,11 @@ module RuboCop
         regopt_include?(:n)
       end
 
+      # @return [Bool] if regexp uses the fixed-encoding regopt
+      def fixed_encoding?
+        regopt_include?(:u)
+      end
+
       private
 
       def regopt_include?(option)
