@@ -1,20 +1,20 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::AST::DefinedNode do
-  let(:defined_node) { parse_source(source).ast }
+  subject(:defined_node) { parse_source(source).ast }
 
   describe '.new' do
     context 'with a defined? node' do
       let(:source) { 'defined? :foo' }
 
-      it { expect(defined_node.is_a?(described_class)).to be(true) }
+      it { is_expected.to be_a(described_class) }
     end
   end
 
   describe '#receiver' do
     let(:source) { 'defined? :foo' }
 
-    it { expect(defined_node.receiver).to eq(nil) }
+    it { expect(defined_node.receiver).to be_nil }
   end
 
   describe '#method_name' do
