@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::AST::Ext::Range do
+  subject(:node) { parse_source(source).ast }
+
   let(:source) { <<~RUBY }
     [
       1,
@@ -8,8 +10,6 @@ RSpec.describe RuboCop::AST::Ext::Range do
     ]
   RUBY
 
-  let(:node) { parse_source(source).ast }
-
   describe '#line_span' do
     it 'returns the range of lines a range occupies' do
       expect(node.loc.begin.line_span).to eq 1..1
