@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
-# Note: specs for `lambda?` and `lambda_literal?` in `send_node_spec`
+# NOTE: specs for `lambda?` and `lambda_literal?` in `send_node_spec`
 RSpec.describe RuboCop::AST::LambdaNode do
   subject(:lambda_node) { parse_source(source).ast }
 
   let(:source) { '->(a, b) { a + b }' }
 
   describe '#receiver' do
-    it { expect(lambda_node.receiver).to eq nil }
+    it { expect(lambda_node.receiver).to be_nil }
   end
 
   describe '#method_name' do
