@@ -49,7 +49,7 @@ RSpec.describe RuboCop::AST::NodePattern do
 
   shared_examples 'nonmatching' do
     it "doesn't match" do
-      expect(result).to be nil
+      expect(result).to be_nil
     end
   end
 
@@ -160,10 +160,10 @@ RSpec.describe RuboCop::AST::NodePattern do
       let(:pattern) { "  (send  42 \n :to_s ) " }
 
       it 'returns true iff the patterns are similar' do
-        expect(instance == instance.dup).to eq true
-        expect(instance == 42).to eq false
-        expect(instance == described_class.new('(send)')).to eq false
-        expect(instance == described_class.new('(send 42 :to_s)')).to eq true
+        expect(instance == instance.dup).to be true
+        expect(instance == 42).to be false
+        expect(instance == described_class.new('(send)')).to be false
+        expect(instance == described_class.new('(send 42 :to_s)')).to be true
       end
     end
   end
@@ -663,6 +663,70 @@ RSpec.describe RuboCop::AST::NodePattern do
 
       it { expect(pattern).to match_code(node) }
     end
+
+    context 'variadic' do
+      context 'with fixed terms' do
+        it 'works for cases with fixed arity before and after union' do
+          expect('(_ { int | sym _ str | } const)').to match_codes(
+            '[X]', '[42, X]', '[:foo, //, "bar", X]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]'
+          )
+        end
+
+        it 'works for cases with variadic terms after union' do
+          expect('(_ { int | sym _ str | } const+)').to match_codes(
+            '[X]', '[42, X, Y, Z]', '[:foo, //, "bar", X]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]'
+          )
+        end
+
+        it 'works for cases with variadic terms before and after union' do
+          expect('(_ const ? { int | sym _ str | } const+)').to match_codes(
+            '[X]', '[FOO, 42, X, Y, Z]', '[:foo, //, "bar", X]', '[X, Y, Z]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]', '[FOO BAR, 42]'
+          )
+        end
+      end
+
+      context 'with variadic terms' do
+        it 'works for cases with fixed arity before and after union' do
+          expect('(_ { sym+ _ str | int* } const)').to match_codes(
+            '[X]', '[42, 666, X]', '[:foo, :foo2, //, "bar", X]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]'
+          )
+        end
+
+        it 'works for cases with variadic terms after union' do
+          expect('(_ { sym+ _ str | int* } const+)').to match_codes(
+            '[X]', '[42, 666, X, Y, Z]', '[:foo, :foo2, //, "bar", X]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]'
+          )
+        end
+
+        it 'works for cases with variadic terms before and after union' do
+          expect('(_ const ? { sym+ _ str | int* } const+)').to match_codes(
+            '[X]', '[FOO, 42, 666, X, Y, Z]', '[:foo, :foo2, //, "bar", X]', '[X, Y, Z]'
+          ).and not_match_codes(
+            '[42]', '[4.2, X]', '["bar", //, :foo, X]', '[FOO BAR, 42]'
+          )
+        end
+      end
+
+      context 'multiple' do
+        it 'works for complex cases' do
+          expect('(_ const ? { sym+ int+ | int+ sym+ } { str+ | regexp+ } ... )').to match_codes(
+            '[X, :foo, :bar, 42, "a", Y]', '[42, 666, :foo, //]'
+          ).and not_match_codes(
+            '[42, :almost, X]', '[X, 42, :foo, 42, //]', '[X, :foo, //, :foo, X]'
+          )
+        end
+      end
+    end
   end
 
   describe 'captures on a wildcard' do
@@ -881,7 +945,7 @@ RSpec.describe RuboCop::AST::NodePattern do
     context 'with complex nesting' do
       let(:pattern) do
         '{(send {$int $float} {$:inc $:dec}) ' \
-        '[!nil {($_ sym $_) (send ($_ $_) :object_id)}]}'
+          '[!nil {($_ sym $_) (send ($_ $_) :object_id)}]}'
       end
       let(:ruby) { '10.object_id' }
       let(:captured_vals) { [:int, 10] }
@@ -1647,14 +1711,22 @@ RSpec.describe RuboCop::AST::NodePattern do
 
       context 'with an ellipsis inside and outside' do
         let(:pattern) { '(array <(str $_) (sym $_) ...> ...)' }
+        let(:captured_vals) { ['world', :hello] }
 
-        it_behaves_like 'invalid'
+        it_behaves_like 'multiple capture'
       end
 
       context 'doubled with ellipsis' do
-        let(:pattern) { '(array <(str $_) ...> <(str $_) ...>)' }
+        let(:pattern) { '(array <(sym $_) ...> <(int $_) ...>)' }
+        let(:captured_vals) { [:hello, 3] }
 
-        it_behaves_like 'invalid'
+        it_behaves_like 'multiple capture'
+      end
+
+      context 'doubled with ellipsis in wrong order' do
+        let(:pattern) { '(array <(int $_) ...> <(sym $_) ...>)' }
+
+        it_behaves_like 'nonmatching'
       end
 
       context 'nested' do
@@ -1684,9 +1756,9 @@ RSpec.describe RuboCop::AST::NodePattern do
       end
 
       context 'with an ellipsis in the same sequence' do
-        let(:pattern) { "(array int #{symbol} ...)" }
+        let(:pattern) { "(array sym #{symbol} ...)" }
 
-        it_behaves_like 'invalid'
+        it { expect(pattern).to match_code(ruby) }
       end
     end
 
@@ -1824,6 +1896,16 @@ RSpec.describe RuboCop::AST::NodePattern do
     end
   end
 
+  describe 'regexp' do
+    it 'matches symbols or strings' do
+      expect('(_ _ $/abc|def|foo/i ...)').to match_codes(
+        'Foo(42)', 'foo(42)'
+      ).and not_match_codes(
+        'bar(42)'
+      )
+    end
+  end
+
   describe 'bad syntax' do
     context 'with empty parentheses' do
       let(:pattern) { '()' }
@@ -1837,6 +1919,24 @@ RSpec.describe RuboCop::AST::NodePattern do
       it_behaves_like 'invalid'
     end
 
+    context 'with empty union subsequence in seq head' do
+      let(:pattern) { '({foo|})' }
+
+      it_behaves_like 'invalid'
+    end
+
+    context 'with unsupported subsequence in seq head within union' do
+      let(:pattern) { '({foo bar+})' }
+
+      it_behaves_like 'invalid'
+    end
+
+    context 'with variadic unions where not supported' do
+      let(:pattern) { '(_ [_ {foo | ...}])' }
+
+      it_behaves_like 'invalid'
+    end
+
     context 'with empty intersection' do
       let(:pattern) { '[]' }
 
@@ -1892,9 +1992,10 @@ RSpec.describe RuboCop::AST::NodePattern do
     end
 
     context 'with doubled ellipsis' do
+      let(:ruby) { 'foo' }
       let(:pattern) { '(send ... ...)' }
 
-      it_behaves_like 'invalid'
+      it { expect(pattern).to match_code(ruby) } # yet silly
     end
 
     context 'with doubled comma in arg list' do
@@ -1923,7 +2024,7 @@ RSpec.describe RuboCop::AST::NodePattern do
 
     it 'yields all children depth first' do
       e = described_class.descend(node)
-      expect(e.instance_of?(Enumerator)).to be(true)
+      expect(e).to be_an_instance_of(Enumerator)
       array, three = node.children
       one, two = array.children
       expect(e.to_a).to eq([node, array, one, 1, two, 2, three, 3])
@@ -1953,18 +2054,21 @@ RSpec.describe RuboCop::AST::NodePattern do
 
     let(:keyword_defaults) { {} }
     let(:method_name) { :my_matcher }
-    let(:line_no) { __LINE__ + 2 }
+    let(:line_no) { __LINE__ + 1 }
+    let(:call_helper) { MyClass.public_send helper_name, method_name, pattern, **keyword_defaults }
     let(:defined_class) do
-      MyClass.public_send helper_name, method_name, pattern, **keyword_defaults
+      call_helper
       MyClass
     end
     let(:ruby) { ':hello' }
     let(:instance) { defined_class.new }
 
-    if Set[1] === 1 # rubocop:disable Style/CaseEquality
-      let(:hello_matcher) { Set[:hello, :foo] }
-    else
-      let(:hello_matcher) { Set[:hello, :foo].method(:include?).to_proc }
+    let(:raise_argument_error) do
+      raise_error do |err|
+        expect(err).to be_a(ArgumentError)
+        expect(err.message).to include('wrong number of arguments')
+        expect(err.backtrace_locations.first.lineno).to be(line_no) if RUBY_ENGINE == 'ruby'
+      end
     end
 
     context 'with a pattern without captures' do
@@ -1973,6 +2077,10 @@ RSpec.describe RuboCop::AST::NodePattern do
       context 'def_node_matcher' do
         let(:helper_name) { :def_node_matcher }
 
+        it 'returns the method name' do
+          expect(call_helper).to eq method_name
+        end
+
         context 'when called on matching code' do
           it { expect(instance).to match_code(node) }
         end
@@ -1987,11 +2095,7 @@ RSpec.describe RuboCop::AST::NodePattern do
           let(:params) { [:extra] }
 
           it 'raises an error with the right location' do
-            expect { result }.to(raise_error do |err|
-              expect(err.is_a?(ArgumentError)).to be(true)
-              expect(err.message).to include('wrong number of arguments')
-              expect(err.backtrace_locations.first.lineno).to be(line_no)
-            end)
+            expect { result }.to(raise_argument_error)
           end
         end
       end
@@ -2000,10 +2104,14 @@ RSpec.describe RuboCop::AST::NodePattern do
         let(:helper_name) { :def_node_search }
         let(:ruby) { 'foo(:hello, :world)' }
 
+        it 'returns the method name' do
+          expect(call_helper).to eq method_name
+        end
+
         context('without a predicate name') do
           context 'when called on matching code' do
             it 'returns an enumerator yielding the matches' do
-              expect(result.is_a?(Enumerator)).to be(true)
+              is_expected.to be_a(Enumerator)
               expect(result.to_a).to match_array [s(:sym, :hello), s(:sym, :world)]
             end
           end
@@ -2012,7 +2120,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:ruby) { 'foo("hello", "world")' }
 
             it 'returns an enumerator yielding nothing' do
-              expect(result.is_a?(Enumerator)).to be(true)
+              is_expected.to be_a(Enumerator)
               expect(result.to_a).to eq []
             end
           end
@@ -2021,11 +2129,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:params) { [:extra] }
 
             it 'raises an error with the right location' do
-              expect { result }.to(raise_error do |err|
-                expect(err.is_a?(ArgumentError)).to be(true)
-                expect(err.message).to include('wrong number of arguments')
-                expect(err.backtrace_locations.first.lineno).to be(line_no)
-              end)
+              expect { result }.to(raise_argument_error)
             end
           end
         end
@@ -2047,11 +2151,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:params) { [:extra] }
 
             it 'raises an error with the right location' do
-              expect { result }.to(raise_error do |err|
-                expect(err.is_a?(ArgumentError)).to be(true)
-                expect(err.message).to include('wrong number of arguments')
-                expect(err.backtrace_locations.first.lineno).to be(line_no)
-              end)
+              expect { result }.to(raise_argument_error)
             end
           end
         end
@@ -2078,11 +2178,7 @@ RSpec.describe RuboCop::AST::NodePattern do
           let(:params) { [:extra] }
 
           it 'raises an error with the right location' do
-            expect { result }.to(raise_error do |err|
-              expect(err.is_a?(ArgumentError)).to be(true)
-              expect(err.message).to include('wrong number of arguments')
-              expect(err.backtrace_locations.first.lineno).to be(line_no)
-            end)
+            expect { result }.to(raise_argument_error)
           end
         end
       end
@@ -2094,16 +2190,16 @@ RSpec.describe RuboCop::AST::NodePattern do
         context('without a predicate name') do
           context 'when called on matching code' do
             it 'returns an enumerator yielding the captures' do
-              expect(result.is_a?(Enumerator)).to be(true)
+              is_expected.to be_a(Enumerator)
               expect(result.to_a).to match_array %i[hello world]
             end
 
             context 'when the pattern contains keyword_params' do
               let(:pattern) { '(sym $%foo)' }
-              let(:keyword_params) { { foo: hello_matcher } }
+              let(:keyword_params) { { foo: Set[:hello, :foo] } }
 
               it 'returns an enumerator yielding the captures' do
-                expect(result.is_a?(Enumerator)).to be(true)
+                is_expected.to be_a(Enumerator)
                 expect(result.to_a).to match_array %i[hello]
               end
 
@@ -2111,8 +2207,8 @@ RSpec.describe RuboCop::AST::NodePattern do
               context 'when helper is called with default keyword_params' do
                 let(:keyword_defaults) { { foo: :world } }
 
-                it 'is overriden when calling the matcher' do
-                  expect(result.is_a?(Enumerator)).to be(true)
+                it 'is overridden when calling the matcher' do
+                  is_expected.to be_a(Enumerator)
                   expect(result.to_a).to match_array %i[hello]
                 end
 
@@ -2120,7 +2216,7 @@ RSpec.describe RuboCop::AST::NodePattern do
                   let(:keyword_params) { {} }
 
                   it 'uses the defaults' do
-                    expect(result.is_a?(Enumerator)).to be(true)
+                    is_expected.to be_a(Enumerator)
                     expect(result.to_a).to match_array %i[world]
                   end
                 end
@@ -2141,7 +2237,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:ruby) { 'foo("hello", "world")' }
 
             it 'returns an enumerator yielding nothing' do
-              expect(result.is_a?(Enumerator)).to be(true)
+              is_expected.to be_a(Enumerator)
               expect(result.to_a).to eq []
             end
           end
@@ -2150,11 +2246,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:params) { [:extra] }
 
             it 'raises an error with the right location' do
-              expect { result }.to(raise_error do |err|
-                expect(err.is_a?(ArgumentError)).to be(true)
-                expect(err.message).to include('wrong number of arguments')
-                expect(err.backtrace_locations.first.lineno).to be(line_no)
-              end)
+              expect { result }.to(raise_argument_error)
             end
           end
         end
@@ -2176,11 +2268,7 @@ RSpec.describe RuboCop::AST::NodePattern do
             let(:params) { [:extra] }
 
             it 'raises an error with the right location' do
-              expect { result }.to(raise_error do |err|
-                expect(err.is_a?(ArgumentError)).to be(true)
-                expect(err.message).to include('wrong number of arguments')
-                expect(err.backtrace_locations.first.lineno).to be(line_no)
-              end)
+              expect { result }.to(raise_argument_error)
             end
           end
         end
@@ -2191,7 +2279,31 @@ RSpec.describe RuboCop::AST::NodePattern do
       let(:pattern) { '(sym %TEST)' }
       let(:helper_name) { :def_node_matcher }
 
-      before { defined_class::TEST = hello_matcher }
+      before { defined_class::TEST = Set[:hello, :foo] }
+
+      it { expect(instance).to match_code(node) }
+
+      context 'when the value is not in the set' do
+        let(:ruby) { ':world' }
+
+        it_behaves_like 'nonmatching'
+      end
+    end
+
+    context 'with a pattern with a namespaced call' do
+      let(:pattern) { '(sym #MyMod.foo)' }
+      let(:helper_name) { :def_node_matcher }
+
+      before do
+        mod = Module.new
+        mod::MyMod = Module.new
+        mod::MyMod.module_eval do
+          def self.foo(val)
+            val == :hello
+          end
+        end
+        defined_class.include mod
+      end
 
       it { expect(instance).to match_code(node) }
 
