@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::AST::RangeNode do
-  let(:range_node) { parse_source(source).ast }
+  subject(:range_node) { parse_source(source).ast }
 
   describe '.new' do
     context 'with an inclusive range' do
@@ -9,8 +9,8 @@ RSpec.describe RuboCop::AST::RangeNode do
         '1..2'
       end
 
-      it { expect(range_node.is_a?(described_class)).to be(true) }
-      it { expect(range_node.range_type?).to be(true) }
+      it { is_expected.to be_a(described_class) }
+      it { is_expected.to be_range_type }
     end
 
     context 'with an exclusive range' do
@@ -18,8 +18,8 @@ RSpec.describe RuboCop::AST::RangeNode do
         '1...2'
       end
 
-      it { expect(range_node.is_a?(described_class)).to be(true) }
-      it { expect(range_node.range_type?).to be(true) }
+      it { is_expected.to be_a(described_class) }
+      it { is_expected.to be_range_type }
     end
 
     context 'with an infinite range' do
@@ -28,8 +28,8 @@ RSpec.describe RuboCop::AST::RangeNode do
         '1..'
       end
 
-      it { expect(range_node.is_a?(described_class)).to be(true) }
-      it { expect(range_node.range_type?).to be(true) }
+      it { is_expected.to be_a(described_class) }
+      it { is_expected.to be_range_type }
     end
 
     context 'with a beignless range' do
@@ -38,8 +38,8 @@ RSpec.describe RuboCop::AST::RangeNode do
         '..42'
       end
 
-      it { expect(range_node.is_a?(described_class)).to be(true) }
-      it { expect(range_node.range_type?).to be(true) }
+      it { is_expected.to be_a(described_class) }
+      it { is_expected.to be_range_type }
     end
   end
 end
