@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::AST::RegexpNode do
-  let(:regexp_node) { parse_source(source).ast }
+  subject(:regexp_node) { parse_source(source).ast }
 
   describe '.new' do
     let(:source) { '/re/' }
 
-    it { expect(regexp_node.is_a?(described_class)).to be(true) }
+    it { is_expected.to be_a(described_class) }
   end
 
   describe '#to_regexp' do
@@ -53,6 +53,18 @@ RSpec.describe RuboCop::AST::RegexpNode do
 
       it { expect(regexp_node.to_regexp.inspect).to eq('/abc/i') }
     end
+
+    context 'with a regexp with an "n" option' do
+      let(:source) { '/abc/n' }
+
+      it { expect(regexp_node.to_regexp.inspect).to eq('/abc/n') }
+    end
+
+    context 'with a regexp with an "u" option' do
+      let(:source) { '/abc/u' }
+
+      it { expect(regexp_node.to_regexp.inspect).to eq('/abc/') }
+    end
   end
 
   describe '#regopt' do
@@ -61,42 +73,42 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with an empty regexp' do
       let(:source) { '//' }
 
-      it { expect(regopt.regopt_type?).to be(true) }
-      it { expect(regopt.children.empty?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
+      it { expect(regopt.children).to be_empty }
     end
 
     context 'with a regexp without option' do
       let(:source) { '/.+/' }
 
-      it { expect(regopt.regopt_type?).to be(true) }
-      it { expect(regopt.children.empty?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
+      it { expect(regopt.children).to be_empty }
     end
 
     context 'with a multi-line regexp without option' do
       let(:source) { "/\n.+\n/" }
 
-      it { expect(regopt.regopt_type?).to be(true) }
-      it { expect(regopt.children.empty?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
+      it { expect(regopt.children).to be_empty }
     end
 
     context 'with an empty regexp with option' do
       let(:source) { '//ix' }
 
-      it { expect(regopt.regopt_type?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
       it { expect(regopt.children).to eq(%i[i x]) }
     end
 
     context 'with a regexp with option' do
       let(:source) { '/.+/imx' }
 
-      it { expect(regopt.regopt_type?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
       it { expect(regopt.children).to eq(%i[i m x]) }
     end
 
     context 'with a multi-line regexp with option' do
       let(:source) { "/\n.+\n/imx" }
 
-      it { expect(regopt.regopt_type?).to be(true) }
+      it { expect(regopt).to be_regopt_type }
       it { expect(regopt.children).to eq(%i[i m x]) }
     end
   end
@@ -182,19 +194,19 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with /-delimiters' do
       let(:source) { '/abc/' }
 
-      it { expect(regexp_node.slash_literal?).to eq(true) }
+      it { is_expected.to be_slash_literal }
     end
 
     context 'with %r/-delimiters' do
       let(:source) { '%r/abc/' }
 
-      it { expect(regexp_node.slash_literal?).to eq(false) }
+      it { is_expected.not_to be_slash_literal }
     end
 
     context 'with %r{-delimiters' do
       let(:source) { '%r{abc}' }
 
-      it { expect(regexp_node.slash_literal?).to eq(false) }
+      it { is_expected.not_to be_slash_literal }
     end
 
     context 'with multi-line %r{-delimiters' do
@@ -206,13 +218,13 @@ RSpec.describe RuboCop::AST::RegexpNode do
         SRC
       end
 
-      it { expect(regexp_node.slash_literal?).to eq(false) }
+      it { is_expected.not_to be_slash_literal }
     end
 
     context 'with %r<-delimiters' do
       let(:source) { '%r<abc>x' }
 
-      it { expect(regexp_node.slash_literal?).to eq(false) }
+      it { is_expected.not_to be_slash_literal }
     end
   end
 
@@ -220,19 +232,19 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with /-delimiters' do
       let(:source) { '/abc/' }
 
-      it { expect(regexp_node.percent_r_literal?).to eq(false) }
+      it { is_expected.not_to be_percent_r_literal }
     end
 
     context 'with %r/-delimiters' do
       let(:source) { '%r/abc/' }
 
-      it { expect(regexp_node.percent_r_literal?).to eq(true) }
+      it { is_expected.to be_percent_r_literal }
     end
 
     context 'with %r{-delimiters' do
       let(:source) { '%r{abc}' }
 
-      it { expect(regexp_node.percent_r_literal?).to eq(true) }
+      it { is_expected.to be_percent_r_literal }
     end
 
     context 'with multi-line %r{-delimiters' do
@@ -244,13 +256,13 @@ RSpec.describe RuboCop::AST::RegexpNode do
         SRC
       end
 
-      it { expect(regexp_node.percent_r_literal?).to eq(true) }
+      it { is_expected.to be_percent_r_literal }
     end
 
     context 'with %r<-delimiters' do
       let(:source) { '%r<abc>x' }
 
-      it { expect(regexp_node.percent_r_literal?).to eq(true) }
+      it { is_expected.to be_percent_r_literal }
     end
   end
 
@@ -296,36 +308,36 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with /-delimiters' do
       let(:source) { '/abc/' }
 
-      it { expect(regexp_node.delimiter?('/')).to eq(true) }
+      it { is_expected.to be_delimiter('/') }
 
-      it { expect(regexp_node.delimiter?('{')).to eq(false) }
+      it { is_expected.not_to be_delimiter('{') }
     end
 
     context 'with %r/-delimiters' do
       let(:source) { '%r/abc/' }
 
-      it { expect(regexp_node.delimiter?('/')).to eq(true) }
+      it { is_expected.to be_delimiter('/') }
 
-      it { expect(regexp_node.delimiter?('{')).to eq(false) }
-      it { expect(regexp_node.delimiter?('}')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%')).to eq(false) }
-      it { expect(regexp_node.delimiter?('r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r/')).to eq(false) }
+      it { is_expected.not_to be_delimiter('{') }
+      it { is_expected.not_to be_delimiter('}') }
+      it { is_expected.not_to be_delimiter('%') }
+      it { is_expected.not_to be_delimiter('r') }
+      it { is_expected.not_to be_delimiter('%r') }
+      it { is_expected.not_to be_delimiter('%r/') }
     end
 
     context 'with %r{-delimiters' do
       let(:source) { '%r{abc}' }
 
-      it { expect(regexp_node.delimiter?('{')).to eq(true) }
-      it { expect(regexp_node.delimiter?('}')).to eq(true) }
+      it { is_expected.to be_delimiter('{') }
+      it { is_expected.to be_delimiter('}') }
 
-      it { expect(regexp_node.delimiter?('/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%')).to eq(false) }
-      it { expect(regexp_node.delimiter?('r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r{')).to eq(false) }
+      it { is_expected.not_to be_delimiter('/') }
+      it { is_expected.not_to be_delimiter('%') }
+      it { is_expected.not_to be_delimiter('r') }
+      it { is_expected.not_to be_delimiter('%r') }
+      it { is_expected.not_to be_delimiter('%r/') }
+      it { is_expected.not_to be_delimiter('%r{') }
     end
 
     context 'with multi-line %r{-delimiters' do
@@ -337,32 +349,32 @@ RSpec.describe RuboCop::AST::RegexpNode do
         SRC
       end
 
-      it { expect(regexp_node.delimiter?('{')).to eq(true) }
-      it { expect(regexp_node.delimiter?('}')).to eq(true) }
+      it { is_expected.to be_delimiter('{') }
+      it { is_expected.to be_delimiter('}') }
 
-      it { expect(regexp_node.delimiter?('/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%')).to eq(false) }
-      it { expect(regexp_node.delimiter?('r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r{')).to eq(false) }
+      it { is_expected.not_to be_delimiter('/') }
+      it { is_expected.not_to be_delimiter('%') }
+      it { is_expected.not_to be_delimiter('r') }
+      it { is_expected.not_to be_delimiter('%r') }
+      it { is_expected.not_to be_delimiter('%r/') }
+      it { is_expected.not_to be_delimiter('%r{') }
     end
 
     context 'with %r<-delimiters' do
       let(:source) { '%r<abc>x' }
 
-      it { expect(regexp_node.delimiter?('<')).to eq(true) }
-      it { expect(regexp_node.delimiter?('>')).to eq(true) }
+      it { is_expected.to be_delimiter('<') }
+      it { is_expected.to be_delimiter('>') }
 
-      it { expect(regexp_node.delimiter?('{')).to eq(false) }
-      it { expect(regexp_node.delimiter?('}')).to eq(false) }
-      it { expect(regexp_node.delimiter?('/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%')).to eq(false) }
-      it { expect(regexp_node.delimiter?('r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r/')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r{')).to eq(false) }
-      it { expect(regexp_node.delimiter?('%r<')).to eq(false) }
+      it { is_expected.not_to be_delimiter('{') }
+      it { is_expected.not_to be_delimiter('}') }
+      it { is_expected.not_to be_delimiter('/') }
+      it { is_expected.not_to be_delimiter('%') }
+      it { is_expected.not_to be_delimiter('r') }
+      it { is_expected.not_to be_delimiter('%r') }
+      it { is_expected.not_to be_delimiter('%r/') }
+      it { is_expected.not_to be_delimiter('%r{') }
+      it { is_expected.not_to be_delimiter('%r<') }
     end
   end
 
@@ -370,19 +382,19 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with direct variable interpoation' do
       let(:source) { '/\n\n#{foo}(abc)+/' }
 
-      it { expect(regexp_node.interpolation?).to eq(true) }
+      it { is_expected.to be_interpolation }
     end
 
     context 'with regexp quote' do
       let(:source) { '/\n\n#{Regexp.quote(foo)}(abc)+/' }
 
-      it { expect(regexp_node.interpolation?).to eq(true) }
+      it { is_expected.to be_interpolation }
     end
 
     context 'with no interpolation returns false' do
       let(:source) { '/a{3,6}/' }
 
-      it { expect(regexp_node.interpolation?).to eq(false) }
+      it { is_expected.not_to be_interpolation }
     end
   end
 
@@ -390,25 +402,25 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with no options' do
       let(:source) { '/x/' }
 
-      it { expect(regexp_node.multiline_mode?).to be(false) }
+      it { is_expected.not_to be_multiline_mode }
     end
 
     context 'with other options' do
       let(:source) { '/x/ix' }
 
-      it { expect(regexp_node.multiline_mode?).to be(false) }
+      it { is_expected.not_to be_multiline_mode }
     end
 
     context 'with only m option' do
       let(:source) { '/x/m' }
 
-      it { expect(regexp_node.multiline_mode?).to be(true) }
+      it { is_expected.to be_multiline_mode }
     end
 
     context 'with m and other options' do
       let(:source) { '/x/imx' }
 
-      it { expect(regexp_node.multiline_mode?).to be(true) }
+      it { is_expected.to be_multiline_mode }
     end
   end
 
@@ -416,25 +428,25 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with no options' do
       let(:source) { '/x/' }
 
-      it { expect(regexp_node.extended?).to be(false) }
+      it { is_expected.not_to be_extended }
     end
 
     context 'with other options' do
       let(:source) { '/x/im' }
 
-      it { expect(regexp_node.extended?).to be(false) }
+      it { is_expected.not_to be_extended }
     end
 
     context 'with only x option' do
       let(:source) { '/x/x' }
 
-      it { expect(regexp_node.extended?).to be(true) }
+      it { is_expected.to be_extended }
     end
 
     context 'with x and other options' do
       let(:source) { '/x/ixm' }
 
-      it { expect(regexp_node.extended?).to be(true) }
+      it { is_expected.to be_extended }
     end
   end
 
@@ -442,25 +454,25 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with no options' do
       let(:source) { '/x/' }
 
-      it { expect(regexp_node.ignore_case?).to be(false) }
+      it { is_expected.not_to be_ignore_case }
     end
 
     context 'with other options' do
       let(:source) { '/x/xm' }
 
-      it { expect(regexp_node.ignore_case?).to be(false) }
+      it { is_expected.not_to be_ignore_case }
     end
 
     context 'with only i option' do
       let(:source) { '/x/i' }
 
-      it { expect(regexp_node.ignore_case?).to be(true) }
+      it { is_expected.to be_ignore_case }
     end
 
     context 'with i and other options' do
       let(:source) { '/x/xim' }
 
-      it { expect(regexp_node.ignore_case?).to be(true) }
+      it { is_expected.to be_ignore_case }
     end
   end
 
@@ -468,25 +480,51 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with no options' do
       let(:source) { '/x/' }
 
-      it { expect(regexp_node.no_encoding?).to be(false) }
+      it { is_expected.not_to be_no_encoding }
     end
 
     context 'with other options' do
       let(:source) { '/x/xm' }
 
-      it { expect(regexp_node.no_encoding?).to be(false) }
+      it { is_expected.not_to be_no_encoding }
     end
 
     context 'with only n option' do
       let(:source) { '/x/n' }
 
-      it { expect(regexp_node.no_encoding?).to be(true) }
+      it { is_expected.to be_no_encoding }
     end
 
     context 'with n and other options' do
       let(:source) { '/x/xnm' }
 
-      it { expect(regexp_node.no_encoding?).to be(true) }
+      it { is_expected.to be_no_encoding }
+    end
+  end
+
+  describe '#fixed_encoding?' do
+    context 'with no options' do
+      let(:source) { '/x/' }
+
+      it { is_expected.not_to be_fixed_encoding }
+    end
+
+    context 'with other options' do
+      let(:source) { '/x/xm' }
+
+      it { is_expected.not_to be_fixed_encoding }
+    end
+
+    context 'with only u option' do
+      let(:source) { '/x/u' }
+
+      it { is_expected.to be_fixed_encoding }
+    end
+
+    context 'with u and other options' do
+      let(:source) { '/x/unm' }
+
+      it { is_expected.to be_fixed_encoding }
     end
   end
 
@@ -494,25 +532,25 @@ RSpec.describe RuboCop::AST::RegexpNode do
     context 'with no options' do
       let(:source) { '/x/' }
 
-      it { expect(regexp_node.single_interpolation?).to be(false) }
+      it { is_expected.not_to be_single_interpolation }
     end
 
     context 'with other options' do
       let(:source) { '/x/xm' }
 
-      it { expect(regexp_node.single_interpolation?).to be(false) }
+      it { is_expected.not_to be_single_interpolation }
     end
 
     context 'with only o option' do
       let(:source) { '/x/o' }
 
-      it { expect(regexp_node.single_interpolation?).to be(true) }
+      it { is_expected.to be_single_interpolation }
     end
 
     context 'with o and other options' do
       let(:source) { '/x/xom' }
 
-      it { expect(regexp_node.single_interpolation?).to be(true) }
+      it { is_expected.to be_single_interpolation }
     end
   end
 end
