@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::AST::SymbolNode do
-  let(:sym_node) { parse_source(source).ast }
+  subject(:sym_node) { parse_source(source).ast }
 
   describe '.new' do
     context 'with a symbol node' do
@@ -9,7 +9,7 @@ RSpec.describe RuboCop::AST::SymbolNode do
         ':foo'
       end
 
-      it { expect(sym_node.is_a?(described_class)).to be(true) }
+      it { is_expected.to be_a(described_class) }
     end
   end
 
