@@ -1,19 +1,19 @@
 # frozen_string_literal: true
 
 RSpec.shared_examples 'wrapped arguments node' do |keyword|
-  let(:return_node) { parse_source(source).ast }
+  subject(:return_node) { parse_source(source).ast }
 
   describe '.new' do
     context 'without arguments' do
       let(:source) { keyword }
 
-      it { expect(return_node.is_a?(described_class)).to be(true) }
+      it { is_expected.to be_a(described_class) }
     end
 
     context 'with arguments' do
       let(:source) { "#{keyword} :foo" }
 
-      it { expect(return_node.is_a?(described_class)).to be(true) }
+      it { is_expected.to be_a(described_class) }
     end
   end
 
@@ -21,13 +21,13 @@ RSpec.shared_examples 'wrapped arguments node' do |keyword|
     context 'with no arguments' do
       let(:source) { keyword }
 
-      it { expect(return_node.arguments.empty?).to be(true) }
+      it { expect(return_node.arguments).to be_empty }
     end
 
     context 'with no arguments and braces' do
       let(:source) { "#{keyword}()" }
 
-      it { expect(return_node.arguments.empty?).to be(true) }
+      it { expect(return_node.arguments).to be_empty }
     end
 
     context 'with a single argument' do
