@@ -8,10 +8,15 @@ if ENV.fetch('COVERAGE', 'f').start_with? 't'
   SimpleCov.start
 end
 
+ENV['RUBOCOP_DEBUG'] = 't'
+
 require 'rubocop-ast'
 if ENV['MODERNIZE']
   RuboCop::AST::Builder.modernize
   RuboCop::AST::Builder.emit_forward_arg = false # inverse of default
+  if RuboCop::AST::Builder.respond_to?(:emit_match_pattern=)
+    RuboCop::AST::Builder.emit_match_pattern = false # inverse of default
+  end
 end
 
 RSpec.shared_context 'ruby 2.3', :ruby23 do
@@ -34,6 +39,18 @@ RSpec.shared_context 'ruby 2.7', :ruby27 do
   let(:ruby_version) { 2.7 }
 end
 
+RSpec.shared_context 'ruby 3.0', :ruby30 do
+  let(:ruby_version) { 3.0 }
+end
+
+RSpec.shared_context 'ruby 3.1', :ruby31 do
+  let(:ruby_version) { 3.1 }
+end
+
+RSpec.shared_context 'ruby 3.2', :ruby32 do
+  let(:ruby_version) { 3.2 }
+end
+
 # ...
 module DefaultRubyVersion
   extend RSpec::SharedContext
